@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: IPAccess.pm,v 1.6 2003/05/29 00:08:44 unimlo Exp $
+# $Id: IPAccess.pm,v 1.8 2003/05/31 16:58:07 unimlo Exp $
 
 package Net::ACL::File::IPAccessRule;
 
@@ -10,7 +10,7 @@ use vars qw( $VERSION @ISA );
 ## Inheritance ##
 
 @ISA     = qw( Net::ACL::Rule );
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 ## Module Imports ##
 
@@ -42,7 +42,7 @@ use vars qw( $VERSION @ISA );
 ## Inheritance ##
 
 @ISA     = qw( Net::ACL::File::Standard );
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 ## Module Imports ##
 
@@ -88,11 +88,12 @@ Net::ACL::File::IPAccess - IP access-lists loaded from configuration string.
 =head1 DESCRIPTION
 
 This module extends the Net::ACL::File::Standard class to handle
-community-lists. See B<Net::ACL::File::Standard> for details.
+community-lists. See L<Net::ACL::File::Standard|Net::ACL::File::Standard> for
+details.
 
 =head1 SEE ALSO
 
-B<Net::ACL>, B<Net::ACL::File>, B<Net::ACL::Standard>
+Net::ACL, Net::ACL::File, Net::ACL::Standard
 
 =head1 AUTHOR
 
