@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: Prefix.pm,v 1.6 2003/05/29 00:08:44 unimlo Exp $
+# $Id: Prefix.pm,v 1.9 2003/05/31 16:58:07 unimlo Exp $
 
 package Net::ACL::File::PrefixRule;
 
@@ -10,7 +10,7 @@ use vars qw( $VERSION @ISA );
 ## Inheritance ##
 
 @ISA     = qw( Net::ACL::Rule );
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 ## Module Imports ##
 
@@ -42,11 +42,11 @@ use vars qw( $VERSION @ISA );
 ## Inheritance ##
 
 @ISA     = qw( Net::ACL::File::Standard );
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 ## Module Imports ##
 
-use Net::ACL::File;
+use Net::ACL::File::Standard;
 use Carp;
 
 ## Net::ACL::File Class Auto Registration Code ##
@@ -87,11 +87,12 @@ Net::ACL::File::Prefix - Prefix-lists loaded from configuration string.
 =head1 DESCRIPTION
 
 This module extends the Net::ACL::File::Standard class to handle
-prefix-lists. See B<Net::ACL::File::Standard> for details.
+prefix-lists. See L<Net::ACL::File::Standard|Net::ACL::File::Standard> for
+details.
 
 =head1 SEE ALSO
 
-B<Net::ACL>, B<Net::ACL::File>, B<Net::ACL::Standard>
+Net::ACL, Net::ACL::File, Net::ACL::Standard
 
 =head1 AUTHOR
 
