@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: Scalar.pm,v 1.6 2003/05/29 00:08:44 unimlo Exp $
+# $Id: Scalar.pm,v 1.8 2003/05/31 16:58:07 unimlo Exp $
 
 package Net::ACL::Set::Scalar;
 
@@ -10,7 +10,7 @@ use vars qw( $VERSION @ISA );
 ## Inheritance and Versioning ##
 
 @ISA     = qw( Net::ACL::Set );
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 ## Module Imports ##
 
@@ -75,7 +75,7 @@ Net::ACL::Set::Scalar - Class replacing a scalar data element
 =head1 DESCRIPTION
 
 This module is a very simpel array ellement replacement utility to allow
-simple value replacement with B<Net::ACL::Rule>.
+simple value replacement with L<Net::ACL::Rule|Net::ACL::Rule>.
 
 =head1 CONSTRUCTOR
 
@@ -102,7 +102,7 @@ constructor and returns them.
 
 =head1 SEE ALSO
 
-B<Net::ACL::Set>, B<Net::ACL::Rule>, B<Net::ACL>
+Net::ACL::Set, Net::ACL::Rule, Net::ACL
 
 =head1 AUTHOR
 
